@@ -13,12 +13,12 @@ use Data::YAML::Writer;
 
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 push @ISA, 'Exporter'; @EXPORT_OK = qw(run print_results);
 
 # comma separated list of default plugins
-my $DEFAULT_PLUGINS = 'Rx,RxCmp,Fib,FibOO,FibMoose,FibMouse,SpamAssassin,Shootout'; # Threads,
+my $DEFAULT_PLUGINS = 'Rx,RxCmp,Fib,FibOO,FibMoose,FibMouse,SpamAssassin,Shootout,MooseTS,RegexpCommonTS';#,Threads
 my $DEFAULT_INDENT  = 0;
 
 # incrementaly interesting Perl Config keys
@@ -55,33 +55,32 @@ sub new {
         bless {}, shift;
 }
 
-# show POD from script/perl-formance
 sub usage
 {
-        print 'perl-formance - Frontend for Benchmark::Perl::Formance
+        print 'benchmark-perlformance - Frontend for Benchmark::Perl::Formance
 
 Usage:
 
-   $ perl-formance
-   $ perl-formance --plugins=SpamAssassin,Rx,RxCmp -v
-   $ perl-formance -ccccc --indent=2
-   $ perl-formance -q
+   $ benchmark-perlformance
+   $ benchmark-perlformance --plugins=SpamAssassin,RegexpCommonTS,RxCmp -v
+   $ benchmark-perlformance -ccccc --indent=2
+   $ benchmark-perlformance -q
 
 If run directly it uses the perl in your PATH:
 
-   $ /path/to/perl-formance
+   $ /path/to/benchmark-perlformance
 
 To use another perl start it via
 
-   $ /other/path/to/bin/perl /path/to/perl-formance
+   $ /other/path/to/bin/perl /path/to/benchmark-perlformance
 
 To provide environment variables (for some plugins) you can do
 
-   $ PERLFORMANCE_TESTMODE_FAST=1 perl-formance
+   $ PERLFORMANCE_TESTMODE_FAST=1 benchmark-perlformance
 
 For more details see
 
-   man perl-formance
+   man benchmark-perlformance
    perldoc Benchmark::Perl::Formance
 
 ';
@@ -90,34 +89,37 @@ For more details see
 sub run {
         my ($self) = @_;
 
-        my $help       = 0;
-        my $showconfig = 0;
-        my $verbose    = 0;
-        my $quiet      = 0;
-        my $plugins    = $DEFAULT_PLUGINS;
-        my $indent     = $DEFAULT_INDENT;
-        my $options    = {};
+        my $help           = 0;
+        my $showconfig     = 0;
+        my $verbose        = 0;
+        my $quiet          = 0;
+        my $options        = {};
+        my $plugins        = $DEFAULT_PLUGINS;
+        my $indent         = $DEFAULT_INDENT;
+        my $tapdescription = "";
 
         # get options
         my $ok = GetOptions (
-                             "help|h"        => \$help,
-                             "quiet|q"       => \$quiet,
-                             "verbose|v+"    => \$verbose,
-                             "showconfig|c+" => \$showconfig,
-                             "plugins=s"     => \$plugins,
-                             "indent=i"      => \$indent,
+                             "help|h"           => \$help,
+                             "quiet|q"          => \$quiet,
+                             "indent=i"         => \$indent,
+                             "plugins=s"        => \$plugins,
+                             "verbose|v+"       => \$verbose,
+                             "showconfig|c+"    => \$showconfig,
+                             "tapdescription=s" => \$tapdescription,
                             );
         do { usage; exit  0 } if $help;
         do { usage; exit -1 } if not $ok;
 
         # fill options
         $self->{options} = $options = {
-                                       help       => $help,
-                                       quiet      => $quiet,
-                                       verbose    => $verbose,
-                                       showconfig => $showconfig,
-                                       plugins    => $plugins,
-                                       indent     => $indent,
+                                       help           => $help,
+                                       quiet          => $quiet,
+                                       verbose        => $verbose,
+                                       showconfig     => $showconfig,
+                                       plugins        => $plugins,
+                                       tapdescription => $tapdescription,
+                                       indent         => $indent,
                                       };
 
         # use forks if requested
@@ -125,7 +127,7 @@ sub run {
         if ($ENV{PERLFORMANCE_USE_FORKS}) {
                 eval "use forks";
                 $use_forks = 1 unless $@;
-                print STDERR "use forks " . ($@ ? "failed" : "") . "\n" if $verbose;
+                print STDERR "# use forks " . ($@ ? "failed" : "") . "\n" if $verbose;
         }
 
         # check plugins
@@ -133,9 +135,9 @@ sub run {
         my @run_plugins = grep {
                 eval "use Benchmark::Perl::Formance::Plugin::$_";
                 if ($@) {
-                        print STDERR "Skip plugin '$_'" if $verbose;
-                        print STDERR ":$@"              if $verbose >= 2;
-                        print STDERR "\n"               if $verbose;
+                        print STDERR "# Skip plugin '$_'" if $verbose;
+                        print STDERR ":$@"                if $verbose >= 2;
+                        print STDERR "\n"                 if $verbose;
                 }
                 not $@;
         } @plugins;
@@ -144,7 +146,7 @@ sub run {
         my %RESULTS;
         foreach (@run_plugins) {
                 no strict 'refs';
-                print STDERR "Run $_...\n" if $verbose;
+                print STDERR "# Run $_...\n" if $verbose;
                 $RESULTS{results}{$_} = &{"Benchmark::Perl::Formance::Plugin::${_}::main"}($options);
         }
 
@@ -183,6 +185,9 @@ sub print_results
         my $yw = new Data::YAML::Writer;
         $yw->write($RESULTS, sub { $output .= shift()."\n" });
         $output =~ s/^/" "x$indent/emsg; # indent
+
+        my $tapdescription = $self->{options}{tapdescription};
+        $output = "ok $tapdescription\n".$output if $tapdescription;
         print $output;
 }
 
@@ -279,7 +284,7 @@ L<http://search.cpan.org/dist/Perl-Formance>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Steffen Schwigon.
+Copyright 2008-2010 Steffen Schwigon.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
